@@ -4,10 +4,11 @@ Interface class for the Bleak representation of a GATT Descriptor
 Created on 2019-06-28 by kevincar <kevincarrolldavis@gmail.com>
 
 """
+
 from CoreBluetooth import CBDescriptor
 
-from bleak.backends.corebluetooth.utils import cb_uuid_to_str
-from bleak.backends.descriptor import BleakGATTDescriptor
+from ..corebluetooth.utils import cb_uuid_to_str
+from ..descriptor import BleakGATTDescriptor
 
 
 class BleakGATTDescriptorCoreBluetooth(BleakGATTDescriptor):
